@@ -3,7 +3,7 @@ import sys
 sys.path.append('.')
 from fast_lineage_caller import utils
 
-def assign_lineage_from_vcf(id_isolate: str, vcf: str, dict_snp_schemes: dict, list_allele_changes_not_same_lineage_reference: list, tag_list: list, print_header: str, out_file: str, rem_redundancy: int) -> None:
+def assign_lineage_from_vcf(id_isolate: str, vcf: str, dict_snp_schemes: dict, list_allele_changes_not_same_lineage_reference: list, tag_list: list, print_header: str, out_file: str, rem_redundancy: int, pass_filter: int) -> None:
     """
     Takes dict with one or multiple SNP schemes, a VCF and the list of positions that define 
     lineage allele changes in the reference and returns the lineage calls
@@ -18,6 +18,11 @@ def assign_lineage_from_vcf(id_isolate: str, vcf: str, dict_snp_schemes: dict, l
                 continue
             else:
                 data_vcf = line.rstrip("\n").split("\t")
+                #check the PASS filter
+                if (pass_filter == 1):
+                    pass_info = data_vcf[6]
+                    if pass_info != "PASS":
+                        continue
                 pos = data_vcf[1]
                 ref_alt = "/".join([data_vcf[3], data_vcf[4]])
                 current_allele = "_".join([pos, ref_alt])
@@ -47,7 +52,7 @@ def assign_lineage_from_vcf(id_isolate: str, vcf: str, dict_snp_schemes: dict, l
     utils.write_down_results(id_isolate, final_lineage_assignments, tag_list, print_header, out_file)
 
 
-def assign_lineage_from_vcf_snp_counts(id_isolate: str, vcf: str, dict_snp_schemes: dict, list_allele_changes_not_same_lineage_reference: list, tag_list: list, print_header: str, out_file: str, rem_redundancy: int) -> None:
+def assign_lineage_from_vcf_snp_counts(id_isolate: str, vcf: str, dict_snp_schemes: dict, list_allele_changes_not_same_lineage_reference: list, tag_list: list, dict_snps_per_tag_lineage: dict, print_header: str, out_file: str, rem_redundancy: int, pass_filter: int) -> None:
     """
     Takes dict with one or multiple SNP schemes, a VCF and the list of positions that define 
     lineage allele changes in the reference and returns the lineage calls
@@ -63,6 +68,11 @@ def assign_lineage_from_vcf_snp_counts(id_isolate: str, vcf: str, dict_snp_schem
                 continue
             else:
                 data_vcf = line.rstrip("\n").split("\t")
+                #check the PASS filter
+                if (pass_filter == 1):
+                    pass_info = data_vcf[6]
+                    if pass_info != "PASS":
+                        continue
                 pos = data_vcf[1]
                 ref_alt = "/".join([data_vcf[3], data_vcf[4]])
                 current_allele = "_".join([pos, ref_alt])
@@ -98,5 +108,5 @@ def assign_lineage_from_vcf_snp_counts(id_isolate: str, vcf: str, dict_snp_schem
     else:
         final_lineage_assignments = lineage_assignments
     #print(final_lineage_assignments)
-    utils.write_down_results_snp_counts(id_isolate, final_lineage_assignments, tag_list, print_header, out_file)
+    utils.write_down_results_snp_counts(id_isolate, final_lineage_assignments, tag_list, dict_snps_per_tag_lineage, print_header, out_file)
 
